A python image to ascii art library
Its usage is simple:!

ITAA: class with all functions of module

ITAA.itaa(img[, rescale, mode, output, use_spaces, invert, enlarge]): image to ascii art function. If mode is 'save' save's text to output, else returns it

ITAA._itaa(img[, rescale, mode, output, invert, enlarge]): old itaa function, with old 25 symbols pallete (new one have 51 symbols)

ITAA.restore_grayscale(img[, output]): restores grayscale from text, generated by itaa function

[Рисунок 4](Рисунок%204.png)

[Polish_20211005_171445034](Polish_20211005_171445034.jpg)
